@@ -1,7 +1,7 @@
-if [ -f bin/bash ]; then
+if [ -f /bin/bash ]; then
   ( cd bin ; cp bash bash.old )
+  ( cd bin ; mv bash.new bash )
 fi
-( cd bin ; mv bash.new bash )
 ( cd bin ; rm -rf sh )
 ( cd bin ; ln -sf bash sh )
 ( cd usr/bin ; rm -rf bash )
